==> postcss-image-inliner-6.0.1.tgz: package/lib/image.js <==
'use strict';

const path = require('path');
const {optimize /* , extendDefaultPlugins */} = require('svgo');
const filesize = require('filesize');
const debug = require('debug')('image-inliner');
const {getResource} = require('asset-resolver');

// Borrowed from https://github.com/filamentgroup/directory-encoder/blob/master/lib/svg-uri-encoder.js
function encodeSvg(content) {
  return (
    encodeURIComponent(
      content
        // Strip newlines and tabs
        .replace(/[\n\r]/gim, '')
        .replace(/\t/gim, ' ')
        // Strip comments
        .replace(/<!--(.*(?=-->))-->/gim, '')
        // Replace
        .replace(/'/gim, '\\i')
    )
      // Encode brackets
      .replace(/\(/g, '%28')
      .replace(/\)/g, '%29')
      // Replace ' with "
      .replace(/'/gm, '"')
  );
}

async function reduceAsync(array = [], reducer = (r) => r, initial) {
  for (const index of array.keys()) {
    initial = await reducer(initial, array[index]); /* eslint-disable-line no-await-in-loop */
  }

  return initial;
}

async function assertSize(resource, maxFileSize) {
  const {mime, contents = ''} = resource || {};
  const encoding = mime === 'image/svg+xml' ? 'utf-8' : 'binary';
  const size = Buffer.byteLength(contents, encoding);
  if (maxFileSize && maxFileSize < size) {
    const message = `Too big.  ${filesize(size)} exceeds the allowed ${filesize(maxFileSize)}`;
    throw new Error(message);
  }

  return resource;
}

async function getDataUri(file, options) {
  // If the url is SVG, let's compress and use the XML directly
  if (file.mime === 'image/svg+xml' && !options.b64Svg) {
    const optimized = await optimize(file.contents.toString('utf-8'), {
      path: file.path,
      multipass: true,
      plugins: options.svgoPlugins,
    });
    return `data:image/svg+xml,${encodeSvg(optimized.data)}`;
  }

  // Otherwise we base64 encode the image
  return `data:${file.mime};base64,${Buffer.from(file.contents, 'binary').toString('base64')}`;
}

async function resolve(filepath, {assetPaths, maxFileSize, resolver = () => undefined}) {
  const filter = (resource) => assertSize(resource, maxFileSize);
  const resolvedFile = await resolver(filepath);
  const base = resolvedFile ? path.dirname(resolvedFile) : assetPaths;
  const file = resolvedFile ? path.basename(resolvedFile) : filepath;

  try {
    return await getResource(file, {base, filter});
  } catch (error) {
    debug(error.message, filepath, 'could not be resolved');
  }
}

function getDataUriMapping(urls = [], options = {}) {
  return reduceAsync(
    [...new Set(urls)],
    async (result, url) => {
      const file = await resolve(url, options);
      if (file && file.mime && /image/.test(file.mime)) {
        result[url] = await getDataUri(file, options);
      }

      return result;
    },
    {}
  );
}

module.exports.getDataUriMapping = getDataUriMapping;

==> postcss-image-inliner-6.1.0.tgz: package/lib/image.js <==
'use strict';

const path = require('path');
const {optimize /* , extendDefaultPlugins */} = require('svgo');
const filesize = require('filesize');
const debug = require('debug')('image-inliner');
const {getResource} = require('asset-resolver');

// Borrowed from https://github.com/filamentgroup/directory-encoder/blob/master/lib/svg-uri-encoder.js
function encodeSvg(content) {
  return (
    encodeURIComponent(
      content
        // Strip newlines and tabs
        .replace(/[\n\r]/gim, '')
        .replace(/\t/gim, ' ')
        // Strip comments
        .replace(/<!--(.*(?=-->))-->/gim, '')
        // Replace
        .replace(/'/gim, '\\i')
    )
      // Encode brackets
      .replace(/\(/g, '%28')
      .replace(/\)/g, '%29')
      // Replace ' with "
      .replace(/'/gm, '"')
  );
}

async function reduceAsync(array = [], reducer = (r) => r, initial) {
  for (const index of array.keys()) {
    initial = await reducer(initial, array[index]); /* eslint-disable-line no-await-in-loop */
  }

  return initial;
}

async function assertSize(resource, maxFileSize, throwError = true) {
  const {mime, contents = ''} = resource || {};
  const encoding = mime === 'image/svg+xml' ? 'utf-8' : 'binary';
  const size = Buffer.byteLength(contents, encoding);
  if (maxFileSize && maxFileSize < size) {
    if (!throwError) return false;

    const message = `Too big.  ${filesize(size)} exceeds the allowed ${filesize(maxFileSize)}`;
    throw new Error(message);
  }

  return resource;
}

async function getDataUri(file, options) {
  // If the url is SVG, let's compress and use the XML directly
  if (file.mime === 'image/svg+xml' && !options.b64Svg) {
    const optimized = await optimize(file.contents.toString('utf-8'), {
      path: file.path,
      multipass: true,
      plugins: options.svgoPlugins,
    });
    return `data:image/svg+xml,${encodeSvg(optimized.data)}`;
  }

  // Otherwise we base64 encode the image
  return `data:${file.mime};base64,${Buffer.from(file.contents, 'binary').toString('base64')}`;
}

async function resolve(filepath, {assetPaths, maxFileSize, largeFileCallback, resolver = () => undefined}) {
  const filter = (resource) => assertSize(resource, maxFileSize, !largeFileCallback);
  const resolvedFile = await resolver(filepath);
  const base = resolvedFile ? path.dirname(resolvedFile) : assetPaths;
  const file = resolvedFile ? path.basename(resolvedFile) : filepath;

  try {
    return await getResource(file, {base, filter});
  } catch (error) {
    debug(error.message, filepath, 'could not be resolved');
  }
}

function getDataUriMapping(urls = [], options = {}) {
  return reduceAsync(
    [...new Set(urls)],
    async (result, url) => {
      const file = await resolve(url, options);
      if (file && file.mime && /image/.test(file.mime)) {
        result[url] = await getDataUri(file, options);
      } else if (options.largeFileCallback) {
        const largeFile = await resolve(url, {...options, maxFileSize: 0});
        if (largeFile && largeFile.mime && /image/.test(largeFile.mime)) {
          result[url] = await options.largeFileCallback(largeFile);
        }
      }

      return result;
    },
    {}
  );
}

module.exports.getDataUriMapping = getDataUriMapping;
